#!/usr/bin/env node

/*
  !/usr/bin/node是告诉操作系统执行这个脚本的时候，调用/usr/bin下的node解释器；
  !/usr/bin/env node这种用法是为了防止操作系统用户没有将node装在默认的/usr/bin路径里。当系统看到这一行的时候，首先会到env设置里查找node的安装路径，再调用对应路径下的解释器程序完成操作。
  !/usr/bin/node相当于写死了node路径;
  !/usr/bin/env node会去环境设置寻找node目录,推荐这种写法
*/

/*
  发布流程：
    1、登录账号，npm login
    2、上传项目，npm publish
  使用流程：
    1、安装项目，npm i yyd-vue-mo -g
    2、拉取github上的对应的项目源码，yyd-vue-mo init
    3、安装依赖，npm i
    4、运行，npm run start
*/

const path = require('path');
const fs = require('fs');

const program = require('commander');
const inquirer = require('inquirer')
const download = require('download-git-repo');
const chalk = require('chalk');
const ora = require('ora');

program
  .version('1.0.0')
  .option('i, init', '初始化yyd-vue-mo项目')

program
  .parse(process.argv);

const nameQuestion = {
  type: 'input',
  message: '项目名称:',
  name: 'name',
  default: 'yyd-vue-mo'
};

const versionQuestion = {
  type: 'input',
  message: '初始版本:',
  name: 'version',
  default: '1.0.0'
};

if (program.init) {
  inquirer.prompt([
    nameQuestion,
    versionQuestion,
  ]).then(function (res) {
    const spinner = ora('正在为您构建项目，请稍后....').start();

    console.log(chalk.gray(JSON.stringify(res)));

    download('yyd19920013/yyd-vue-mo', res.name, function (err) {
      if(!err){
        // 可以输出一些项目成功的信息
        console.log(chalk.blueBright(`构建项目成功，cd ${res.name}，输入cnpm i进行依赖安装，npm run start运行项目`));

        //修改package.json中的用户自定义信息
        fs.readFile(`${process.cwd()}/${res.name}/package.json`, (err, data) => {
          if (err) throw err;
          let _data = JSON.parse(data.toString());

          _data.name = res.name;
          _data.version = res.version;

          let str = JSON.stringify(_data, null, 4);

          fs.writeFile(`${process.cwd()}/${res.name}/package.json`, str, function (err) {
            if (err) throw err;
            process.exit();
          })
        });
      }else{
        // 可以输出一些项目失败的信息
        spinner.warn(['发生错误，请在https://github.com/yyd19920013，Issues留言']);
        process.exit();
      }
    })
  });
}
